@@ -4,4 +4,5 @@ from django.apps import AppConfig
 class LocationConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
     name = 'xj_location'
-    verbose_name = u'定位模块'
+    verbose_name = u'Ⅻ 定位模块'
+    sort = 12
